@@ -13,7 +13,7 @@ pub struct Bearing {
 }
 
 #[repr(C)]
-#[derive(Clone)]
+#[derive(Clone, PartialEq)]
 pub enum Approach {
     UNRESTRICTED,
     CURB,
@@ -679,6 +679,18 @@ impl GeneralOptions {
         self.exclude = val.clone();
         self
     }
+
+    pub fn validate(&mut self) -> Result<(), String> {
+        if let Some(approaches) = &self.approach {
+            if self.coordinate.len() != approaches.len() {
+                return Err("num_of_approaches not matching num_of_coords".to_owned());
+            }
+            if approaches.contains(&None) {
+                return Err("Do not put None value in approaches".to_owned());
+            }
+        }
+        Ok(())
+    }
 }
 
 #[repr(C)]
